.. _errors_reference:

Error classes
*************

.. autoexception:: craft_platforms.CraftPlatformsError
    :members:


Architecture-related errors
---------------------------

.. autoexception:: craft_platforms.AllOnlyBuildError
    :members:

Base-related errors
-------------------

.. autoexception:: craft_platforms.InvalidBaseError
    :members:

.. autoexception:: craft_platforms.NeedBuildBaseError
    :members:

.. autoexception:: craft_platforms.RequiresBaseError
    :members:

Platform-related errors
-----------------------

.. autoexception:: craft_platforms.AllSinglePlatformError
    :members:

.. autoexception:: craft_platforms.InvalidPlatformNameError
    :members:

.. autoexception:: craft_platforms.InvalidPlatformError
    :members:
